<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AddLayer</name>
    <message>
        <location filename="../AddLayerInit.js" line="+2"/>
        <source>&amp;Add Layer</source>
        <translation>&amp;Ajouter un calque</translation>
    </message>
    <message>
        <location filename="../AddLayer.js" line="+35"/>
        <source>Layer</source>
        <translation>Calque</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Add Layer</source>
        <translation>Ajouter un calque</translation>
    </message>
</context>
<context>
    <name>Layer</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+33"/>
        <source>Default color for new layers:</source>
        <translation>Couleur par défaut pour nouveaux calques :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Default lineweight for layer 0:</source>
        <translation>Épaisseur de ligne par défaut pour calque 0 :</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Default color for layer 0:</source>
        <translation>Couleur par défaut pour calque 0 :</translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Default lineweight for new layers:</source>
        <translation>Épaisseur de ligne par défaut pour nouveaux calques :</translation>
    </message>
</context>
</TS>
